Structs
Buffer of uninitialized bytes to serve as workspace for dynamic arrays.
Functions
Allocate a memory buffer with sufficient storage for the given stack requirements, using the global allocator, or an error if the allocation did not succeed.
Allocate a memory buffer with sufficient storage for the given stack requirements, using the global allocator.